@@ -34,5 +34,4 @@ ${SCRIPT_DIR}/wait-for-kafka.sh
 [ -f integration-test.log ] && rm integration-test.log
 
 # run integration tests
-go install gotest.tools/gotestsum@latest
-gotestsum --format testname -- -run Integration ./...
+go tool gotestsum --format testname -- -run Integration ./...
