@@ -50,6 +50,15 @@ type ProtobufConfig struct {
 	ProtosetFiles    []string
 	ProtoFiles       []string
 	ProtoImportPaths []string
+	MarshalOptions   ProtobufMarshalOptions
+}
+
+type ProtobufMarshalOptions struct {
+	AllowPartial      bool
+	UseProtoNames     bool
+	UseEnumNumbers    bool
+	EmitUnpopulated   bool
+	EmitDefaultValues bool
 }
 
 type AvroConfig struct {
