@@ -1,9 +1,9 @@
 package consume
 
 import (
-	"github.com/golang/protobuf/ptypes/empty"
 	"google.golang.org/protobuf/reflect/protoreflect"
 	"google.golang.org/protobuf/reflect/protoregistry"
+	"google.golang.org/protobuf/types/known/emptypb"
 )
 
 // An implementation of protojson's Resolver interface.
@@ -16,12 +16,12 @@ func (*ignoreUnrecognizedAny) FindMessageByName(name protoreflect.FullName) (pro
 	if result, err := protoregistry.GlobalTypes.FindMessageByName(name); err == nil {
 		return result, nil
 	}
-	return (&empty.Empty{}).ProtoReflect().Type(), nil
+	return (&emptypb.Empty{}).ProtoReflect().Type(), nil
 }
 
 func (*ignoreUnrecognizedAny) FindMessageByURL(url string) (protoreflect.MessageType, error) {
 	if result, err := protoregistry.GlobalTypes.FindMessageByURL(url); err == nil {
 		return result, nil
 	}
-	return (&empty.Empty{}).ProtoReflect().Type(), nil
+	return (&emptypb.Empty{}).ProtoReflect().Type(), nil
 }
